==> xwidgetsbase-8.6.4.tar.gz: lib/XWidgets/XDD/XDDSearch.dart <==
part of xwidgetbase;

class XDDSearch<T> extends StatefulWidget {
  XDDSearch({
    Key? key,
    required this.liItems,
    required this.colorStyleDD,
    required this.onChangedItemOfDD,
    required this.labelOfDD,
    this.colorOfTitleDD,
    this.propToShowInItems,
    this.itemWidgetBuilder,
    this.backGroundColorForPopUp,
    this.colorForSearchBoxBorderANDlabel,
    this.clearBTN,
    this.onPressedClearButton,
    this.dropdownSearchBaseStyle,
    this.selectedItem,
    this.colorThemeForStyle,
    this.colorBorderANDlabel,
    this.colorIconClear,
    this.dropDownButton,
    this.colorOfLabel,
    this.itemAsString,
    this.onFind,
    this.focusColorOfDD,
    this.floatingLabelBehavior,
    this.visible_SearchBox,
    this.ddMode = "Dialog",
    this.visible_clearBTN = true,
    this.contentPadding,
    this.autoValidateMode = AutovalidateMode.disabled,
  }) : super(key: key);
  T? selectedItem;
  final List<T> liItems;
  final Color? colorStyleDD;
  final Color? backGroundColorForPopUp;
  final Color? colorForSearchBoxBorderANDlabel;
  final ValueChanged? onChangedItemOfDD;
  final String? labelOfDD;
  final Color? colorOfTitleDD;
  final String? propToShowInItems;
  final Function()? onPressedClearButton;
  final Widget? clearBTN;
  final bool visible_clearBTN;
  final bool? visible_SearchBox;
  final Widget? dropDownButton;
  final TextStyle? dropdownSearchBaseStyle;
  final DropdownSearchPopupItemBuilder<T>? itemWidgetBuilder;
  final Color? colorThemeForStyle;
  final Color? colorBorderANDlabel;
  final Color? colorIconClear;
  final Color? colorOfLabel;
  final String Function(T)? itemAsString;
  final Future<List<T>> Function(String)? onFind;
  final AutovalidateMode? autoValidateMode;
  final Color? focusColorOfDD;
  final FloatingLabelBehavior? floatingLabelBehavior;
  final EdgeInsetsGeometry? contentPadding;

  ///Metti "Dialog" per avere un AlertDialog, metti "Menu" per avere solo un DDpopup
  final String? ddMode;
  @override
  _XDDSearchState<T> createState() => _XDDSearchState<T>();
}

class _XDDSearchState<T> extends State<XDDSearch<T>> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
        asyncItems: widget.onFind,
        autoValidateMode: widget.autoValidateMode,
        dropdownButtonProps: DropdownButtonProps(
          constraints: BoxConstraints(maxHeight: 100, minHeight: 70),
          color: widget.colorStyleDD,
          icon: widget.dropDownButton ?? Icon(Icons.arrow_downward_sharp, color: widget.colorIconClear ?? Colors.black),
        ),
        dropdownDecoratorProps: DropDownDecoratorProps(
            dropdownSearchDecoration: InputDecoration(
              contentPadding: widget.contentPadding ?? EdgeInsets.only(left: 5),
              hintText: "",
              floatingLabelBehavior: widget.floatingLabelBehavior ?? FloatingLabelBehavior.never,
              label: Text(widget.labelOfDD ?? ""),
              fillColor: widget.colorStyleDD,
              focusColor: widget.focusColorOfDD,
              filled: true,
              labelStyle: XStyles.xStyTextForDescr(widget.colorOfLabel ?? widget.colorBorderANDlabel ?? Colors.black),
              hintStyle: XStyles.xStyTextForSubDescr(widget.colorOfLabel ?? widget.colorBorderANDlabel ?? Colors.black),
              border: inputDecorationForDD(widget.colorBorderANDlabel ?? Colors.white),
              disabledBorder: inputDecorationForDD(widget.colorBorderANDlabel ?? Colors.white),
              enabledBorder: inputDecorationForDD(widget.colorBorderANDlabel ?? Colors.white),
            ),
            baseStyle: widget.dropdownSearchBaseStyle ?? XStyles.xStyTextForSubDescr(widget.colorOfLabel)),
        // mode: Mode.DIALOG,
        popupProps: widget.ddMode == "Dialog"
            ? PopupProps.dialog(
                searchFieldProps: TextFieldProps(
                  decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.colorForSearchBoxBorderANDlabel),
                ),
                fit: FlexFit.loose,
                showSearchBox: widget.visible_SearchBox ?? true,
                title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
                dialogProps: DialogProps(backgroundColor: widget.backGroundColorForPopUp ?? widget.colorStyleDD),
                itemBuilder: widget.itemWidgetBuilder != null
                    ? widget.itemWidgetBuilder
                    : ((context, item, isSelected) {
                        return Card(
                            child: Container(
                                height: 35,
                                alignment: Alignment.center,
                                child: Text(
                                  widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!],
                                  textAlign: TextAlign.center,
                                )));
                      }),
              )
            : PopupProps.menu(
                searchFieldProps: TextFieldProps(
                  decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.colorForSearchBoxBorderANDlabel),
                ),
                fit: FlexFit.loose,
                showSearchBox: widget.visible_SearchBox ?? true,
                title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7, bottom: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
                itemBuilder: widget.itemWidgetBuilder != null
                    ? widget.itemWidgetBuilder
                    : ((context, item, isSelected) {
                        return Card(child: Container(height: 35, alignment: Alignment.center, child: Text(widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!])));
                      })),
        items: widget.liItems,
        selectedItem: widget.selectedItem,
        clearButtonProps: ClearButtonProps(
          icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.colorIconClear ?? Colors.black),
          isVisible: widget.visible_clearBTN,
        ),
        onChanged: (value) {
          widget.onChangedItemOfDD!(value);
        },
        itemAsString: widget.itemAsString == null
            ? (i) {
                if (widget.propToShowInItems == null) {
                  return (" " + i.toString());
                } else {
                  return (i as dynamic)[widget.propToShowInItems];
                }
              }
            : widget.itemAsString
        // serve solo per avere il valore iniziale      selectedItem: _objForDD == null ? _objForDD : (_objForDD as dynamic)[widget.propToShowInItems!],
        );
    return Container(child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Color(0xFF57cc99)),
      border: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(colorBorderANDlabelForSearchBox),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.black),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
    );
  }
}

==> xwidgetsbase-8.6.8.tar.gz: lib/XWidgets/XDD/XDDSearch.dart <==
part of xwidgetbase;

class XDDSearch<T> extends StatefulWidget {
  XDDSearch({
    Key? key,
    required this.liItems,
    required this.colorStyleDD,
    required this.onChangedItemOfDD,
    required this.labelOfDD,
    this.colorOfTitleDD,
    this.propToShowInItems,
    this.itemWidgetBuilder,
    this.backGroundColorForPopUp,
    this.colorForSearchBoxBorderANDlabel,
    this.clearBTN,
    this.onPressedClearButton,
    this.dropdownSearchBaseStyle,
    this.selectedItem,
    this.colorThemeForStyle,
    this.colorBorderANDlabel,
    this.colorIconClear,
    this.dropDownButton,
    this.colorOfLabel,
    this.itemAsString,
    this.onFind,
    this.focusColorOfDD,
    this.floatingLabelBehavior,
    this.visible_SearchBox,
    this.ddMode = "Dialog",
    this.visible_clearBTN = true,
    this.contentPadding,
    this.dropdownBuilder,
    this.autoValidateMode = AutovalidateMode.disabled,
  }) : super(key: key);
  T? selectedItem;
  final List<T> liItems;
  final Color? colorStyleDD;
  final Color? backGroundColorForPopUp;
  final Color? colorForSearchBoxBorderANDlabel;
  final ValueChanged? onChangedItemOfDD;
  final String? labelOfDD;
  final Color? colorOfTitleDD;
  final String? propToShowInItems;
  final Function()? onPressedClearButton;
  final Widget? clearBTN;
  final bool visible_clearBTN;
  final bool? visible_SearchBox;
  final Widget? dropDownButton;
  final TextStyle? dropdownSearchBaseStyle;
  final DropdownSearchPopupItemBuilder<T>? itemWidgetBuilder;
  final Color? colorThemeForStyle;
  final Color? colorBorderANDlabel;
  final Color? colorIconClear;
  final Color? colorOfLabel;
  final String Function(T)? itemAsString;
  final Future<List<T>> Function(String)? onFind;
  final AutovalidateMode? autoValidateMode;
  final Color? focusColorOfDD;
  final FloatingLabelBehavior? floatingLabelBehavior;
  final EdgeInsetsGeometry? contentPadding;
  final Widget Function(BuildContext, T?)? dropdownBuilder;

  ///Metti "Dialog" per avere un AlertDialog, metti "Menu" per avere solo un DDpopup
  final String? ddMode;
  @override
  _XDDSearchState<T> createState() => _XDDSearchState<T>();
}

class _XDDSearchState<T> extends State<XDDSearch<T>> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
        asyncItems: widget.onFind,
        autoValidateMode: widget.autoValidateMode,
        dropdownButtonProps: DropdownButtonProps(
          color: widget.colorStyleDD,
          icon: widget.dropDownButton ?? Icon(Icons.arrow_downward_sharp, color: widget.colorIconClear ?? Colors.black),
        ),
        dropdownDecoratorProps: DropDownDecoratorProps(
            dropdownSearchDecoration: InputDecoration(
              contentPadding: widget.contentPadding ?? EdgeInsets.only(left: 5),
              hintText: "",
              floatingLabelBehavior: widget.floatingLabelBehavior ?? FloatingLabelBehavior.never,
              label: Text(widget.labelOfDD ?? "", style: XStyles.xStyTextForTextBase(widget.colorOfLabel ?? widget.colorBorderANDlabel ?? Colors.black)),
              fillColor: widget.colorStyleDD,
              focusColor: widget.focusColorOfDD,
              filled: true,
              labelStyle: XStyles.xStyTextForTextBase(widget.colorOfLabel ?? widget.colorBorderANDlabel ?? Colors.black),
              hintStyle: XStyles.xStyTextForSubDescr(widget.colorOfLabel ?? widget.colorBorderANDlabel ?? Colors.black),
              border: inputDecorationForDD(widget.colorBorderANDlabel ?? Colors.white),
              disabledBorder: inputDecorationForDD(widget.colorBorderANDlabel ?? Colors.white),
              enabledBorder: inputDecorationForDD(widget.colorBorderANDlabel ?? Colors.white),
            ),
            baseStyle: widget.dropdownSearchBaseStyle ?? XStyles.xStyTextForSubDescr(widget.colorOfLabel)),
        // mode: Mode.DIALOG,
        popupProps: widget.ddMode == "Dialog"
            ? PopupProps.dialog(
                searchFieldProps: TextFieldProps(
                  decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.colorForSearchBoxBorderANDlabel),
                ),
                fit: FlexFit.loose,
                showSearchBox: widget.visible_SearchBox ?? true,
                title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
                dialogProps: DialogProps(backgroundColor: widget.backGroundColorForPopUp ?? widget.colorStyleDD),
                itemBuilder: widget.itemWidgetBuilder != null
                    ? widget.itemWidgetBuilder
                    : ((context, item, isSelected) {
                        return Card(
                            child: Container(
                                height: 35,
                                alignment: Alignment.center,
                                child: Text(
                                  widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!],
                                  textAlign: TextAlign.center,
                                )));
                      }),
              )
            : PopupProps.menu(
                searchFieldProps: TextFieldProps(
                  decoration: inputDecorationDD_searchBox(colorBorderANDlabelForSearchBox: widget.colorForSearchBoxBorderANDlabel),
                ),
                fit: FlexFit.loose,
                showSearchBox: widget.visible_SearchBox ?? true,
                title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7, bottom: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
                itemBuilder: widget.itemWidgetBuilder != null
                    ? widget.itemWidgetBuilder
                    : ((context, item, isSelected) {
                        return Card(child: Container(height: 35, alignment: Alignment.center, child: Text(widget.itemAsString != null ? item : (item as dynamic)[widget.propToShowInItems!])));
                      })),
        items: widget.liItems,
        selectedItem: widget.selectedItem,
        clearButtonProps: ClearButtonProps(
          icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.colorIconClear ?? Colors.black),
          isVisible: widget.visible_clearBTN,
        ),
        onChanged: (value) {
          widget.onChangedItemOfDD!(value);
        },
        itemAsString: widget.itemAsString == null
            ? (i) {
                if (widget.propToShowInItems == null) {
                  return (" " + i.toString());
                } else {
                  return (i as dynamic)[widget.propToShowInItems];
                }
              }
            : widget.itemAsString,
        dropdownBuilder: widget.dropdownBuilder
        // serve solo per avere il valore iniziale      selectedItem: _objForDD == null ? _objForDD : (_objForDD as dynamic)[widget.propToShowInItems!],
        );
    return Container(child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Color(0xFF57cc99)),
      border: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(colorBorderANDlabelForSearchBox),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.black),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
    );
  }
}
